@@ -21,6 +21,10 @@
 #define BINGPROVIDER_H
 
 #include "potdprovider.h"
+// Qt
+#include <QImage>
+
+class KJob;
 
 /**
  * This class provides the image for the Bing's homepage
@@ -42,7 +46,7 @@ class BingProvider : public PotdProvider
         /**
          * Destroys the Bing provider.
          */
-        ~BingProvider();
+        ~BingProvider() override;
 
         /**
          * Returns the requested image.
@@ -50,15 +54,14 @@ class BingProvider : public PotdProvider
          * Note: This method returns only a valid image after the
          *       finished() signal has been emitted.
          */
-        QImage image() const Q_DECL_OVERRIDE;
+        QImage image() const override;
 
     private:
-      class Private;
-      Private* const d;
+        void pageRequestFinished(KJob *job);
+        void imageRequestFinished(KJob *job);
 
-      Q_PRIVATE_SLOT( d, void pageRequestFinished( KJob* ) )
-      Q_PRIVATE_SLOT( d, void imageRequestFinished( KJob* ) )
+    private:
+        QImage mImage;
 };
 
 #endif
-
